@@ -45,17 +45,17 @@ TESTFILE = os.path.join(tempfile.gettempdir(), "percache.tests")
 class TestCase(unittest.TestCase):
 
     def __init__(self, *args):
-    
+
         if os.path.exists(TESTFILE):
             os.remove(TESTFILE)
         super(TestCase, self).__init__(*args)
-    
+
     def setUp(self):
         unittest.TestCase.setUp(self)
-        
+
     def tearDown(self):
         unittest.TestCase.tearDown(self)
-        
+
     def call(self, fn, name, args, kwargs, result, cached):
         expstr = "expecting %s result" % (cached and "cached" or "new")
         print("calling %s(%s | %s) (%s)" % (name, args, kwargs, expstr))
@@ -65,22 +65,22 @@ class TestCase(unittest.TestCase):
         self.assertTrue(result == r)
 
     def test_1(self):
-        """Test differentiation of basic numeric arguments.""" 
-        
+        """Test differentiation of basic numeric arguments."""
+
         c = Cache(TESTFILE)
-        
-        @c.check
+
+        @c
         def f1(a, b):
             print("computing new result")
             self.frun = True
             return a
 
-        @c.check
+        @c
         def f2(a, b):
             print("computing new result")
             self.frun = True
             return a
-        
+
         self.call(f1, "f1", (1,2), {}, 1, False)
         self.call(f1, "f1", (1,2), {}, 1, True)
         self.call(f1, "f1", (1,2L), {}, 1, False)
@@ -97,18 +97,18 @@ class TestCase(unittest.TestCase):
 
         c = Cache(TESTFILE)
 
-        @c.check
+        @c
         def f1(a, b):
             print("computing new result")
             self.frun = True
             return a
 
-        @c.check
+        @c
         def f2(a, b):
             print("computing new result")
             self.frun = True
             return a
-        
+
         c = Cache(TESTFILE)
 
         self.call(f1, "f1", (1,2), {}, 1, True)
@@ -117,15 +117,15 @@ class TestCase(unittest.TestCase):
         self.call(f2, "f2", (1,3), {}, 1, True)
         self.call(f2, "f2", ("2",3), {}, "2", False)
         self.call(f2, "f2", ("2",3), {}, "2", True)
-        
+
         c.close()
-        
+
     def test_3(self):
         """Test differentiation of normal and unicode strings."""
 
         c = Cache(TESTFILE)
-        
-        @c.check
+
+        @c
         def f3(s):
             print("computing new result")
             self.frun = True
@@ -140,13 +140,13 @@ class TestCase(unittest.TestCase):
 
     def test_4(self):
         """Free"""
-        
+
     def test_5(self):
         """Test clearing of old cached results."""
 
         c = Cache(TESTFILE)
-        
-        @c.check
+
+        @c
         def f5(a):
             print("computing new result")
             self.frun = True
@@ -165,10 +165,10 @@ class TestCase(unittest.TestCase):
 
     def test_6(self):
         """Test keyword arguments."""
-        
+
         c = Cache(TESTFILE)
-        
-        @c.check
+
+        @c
         def f6(a, x=1, y=2, z=3):
             print("computing new result")
             self.frun = True
@@ -186,7 +186,7 @@ class TestCase(unittest.TestCase):
         """Test overridden __repr__ method."""
 
         c = Cache(TESTFILE)
-        
+
         class X(object):
             def __init__(self, a):
                 self.a = a
@@ -195,8 +195,8 @@ class TestCase(unittest.TestCase):
         class Y(object):
             def __init__(self, a):
                 self.a = a
-        
-        @c.check
+
+        @c
         def f7(a):
             print("computing new result")
             self.frun = True
@@ -205,9 +205,9 @@ class TestCase(unittest.TestCase):
         self.call(f7, "f7", (X(1),), {}, 0, False)
         self.call(f7, "f7", (X(1),), {}, 0, True)
         self.call(f7, "f7", (X(2),), {}, 0, False)
-        
+
         y1, y2 = Y(1), Y(1)
-        
+
         self.call(f7, "f7", (y1,), {}, 0, False)
         self.call(f7, "f7", (y2,), {}, 0, False) # bad __repr__ method
 
@@ -220,10 +220,10 @@ class TestCase(unittest.TestCase):
             return "foobar"
 
         c = Cache(TESTFILE, repr=myrepr)
-        
+
         class X(object): pass
-        
-        @c.check
+
+        @c
         def f8(a):
             print("computing new result")
             self.frun = True
@@ -237,7 +237,105 @@ class TestCase(unittest.TestCase):
 
         c.close()
 
+    def test_check(self):
+        """Test if old `check` interface still works."""
+
+        c = Cache(TESTFILE)
+
+        @c.check
+        def f1(a, b):
+            print("computing new result")
+            self.frun = True
+            return a
+
+        @c.check
+        def f2(a, b):
+            print("computing new result")
+            self.frun = True
+            return a
+
+        self.call(f1, "f1", (1,2), {}, 1, False)
+        self.call(f1, "f1", (1,2), {}, 1, True)
+        self.call(f1, "f1", (1,2L), {}, 1, False)
+        self.call(f1, "f1", (1,3), {}, 1, False)
+        self.call(f2, "f2", (1,3), {}, 1, False)
+        self.call(f2, "f2", (1,3), {}, 1, True)
+        self.call(f2, "f2", (1.1,0.1), {}, 1.1, False)
+        self.call(f2, "f2", (1.1,0.1), {}, 1.1, True)
+
+        c.close()
+
+    def test_alternative_backend(self):
+        """Test alternative backend and live-sync mode."""
+
+        class Backend(dict):
+            """Dummy backend."""
+            closed = False
+            synced = False
+            def close(self):
+                self.closed = True
+            def sync(self):
+                self.synced = True
+
+        b = Backend()
+        c = Cache(b, livesync=True)
+
+        @c
+        def f1(a, b):
+            print("computing new result")
+            self.frun = True
+            return a
+
+        @c
+        def f2(a, b):
+            print("computing new result")
+            self.frun = True
+            return a
+
+        self.call(f1, "f1", (1,2), {}, 1, False)
+        self.call(f1, "f1", (1,2), {}, 1, True)
+        self.call(f1, "f1", (1,2L), {}, 1, False)
+        self.call(f1, "f1", (1,3), {}, 1, False)
+        self.call(f2, "f2", (1,3), {}, 1, False)
+        self.call(f2, "f2", (1,3), {}, 1, True)
+        self.call(f2, "f2", (1.1,0.1), {}, 1.1, False)
+        self.call(f2, "f2", (1.1,0.1), {}, 1.1, True)
+
+        self.assertTrue(b.synced)
+        self.assertFalse(b.closed)
+        c.close()
+        self.assertTrue(b.closed)
+
+        # now without live-sync
+
+        b = Backend()
+        c = Cache(b, livesync=False)
+
+        @c
+        def f3(a, b):
+            print("computing new result")
+            self.frun = True
+            return a
+
+        @c
+        def f4(a, b):
+            print("computing new result")
+            self.frun = True
+            return a
+
+        self.call(f3, "f1", (1,2), {}, 1, False)
+        self.call(f3, "f1", (1,2), {}, 1, True)
+        self.call(f3, "f1", (1,2L), {}, 1, False)
+        self.call(f3, "f1", (1,3), {}, 1, False)
+        self.call(f4, "f2", (1,3), {}, 1, False)
+        self.call(f4, "f2", (1,3), {}, 1, True)
+        self.call(f4, "f2", (1.1,0.1), {}, 1.1, False)
+        self.call(f4, "f2", (1.1,0.1), {}, 1.1, True)
+
+        self.assertFalse(b.synced)
+        c.close()
+
 if __name__ == '__main__':
 
     unittest.main()
-    
\ No newline at end of file
+
